@@ -455,7 +455,12 @@ def patched_add_url_rule(wrapped, instance, args, kwargs):
             #   should we do something special with these views? Change the name/resource? Add tags?
             core.dispatch("service_entrypoint.patch", (unwrap(view_func),))
             wrapped_view = wrap_view(instance, view_func, name=endpoint, resource=rule)
-        for method in kwargs.get("methods", []):
+        methods = kwargs.get("methods", ["GET"])
+        try:
+            methods = iter(methods)
+        except Exception:  # nosec
+            methods = ["GET"]
+        for method in methods:
             endpoint_collection.add_endpoint(method, rule, operation_name="flask.request")
         return wrapped(
             rule,
