@@ -1,9 +1,9 @@
 from tornado import template
 
 from ddtrace import config
+from ddtrace._trace.pin import Pin
 from ddtrace.ext import SpanTypes
 from ddtrace.internal.constants import COMPONENT
-from ddtrace.trace import Pin
 
 
 def generate(func, renderer, args, kwargs):
