@@ -17,6 +17,7 @@ class SpanTypes(object):
     SYSTEM = "system"
     LLM = "llm"
     VALKEY = "valkey"
+    WEBSOCKET = "websocket"
 
 
 class SpanKind(object):
@@ -27,6 +28,11 @@ class SpanKind(object):
     INTERNAL = "internal"
 
 
+class SpanLinkKind(object):
+    EXECUTED = "executed_by"
+    RESUMING = "resuming"
+
+
 EXIT_SPAN_TYPES = frozenset(
     {
         SpanTypes.CACHE,
