@@ -235,6 +235,10 @@ class TestVisibilityItemBase(abc.ABC):
         self._add_all_tags_to_span()
         self._span.finish(finish_time=override_finish_time)
 
+        parent_span = self.get_parent_span()
+        if parent_span:
+            self._tracer.context_provider.activate(parent_span)
+
     def _set_default_tags(self) -> None:
         """Applies the tags that should be on every span regardless of the item type
 
@@ -617,18 +621,19 @@ class TestVisibilityParentItem(TestVisibilityItemBase, Generic[CIDT, CITEMT]):
             # Respect override status no matter what
             self.set_status(override_status)
 
+        if force:
+            # Finish all children regardless of their status
+            for child in self._children.values():
+                if not child.is_finished():
+                    child.finish(force=force)
+            self.set_status(self.get_raw_status())
+
         item_status = self.get_status()
 
-        if item_status == SPECIAL_STATUS.UNFINISHED:
-            if force:
-                # Finish all children regardless of their status
-                for child in self._children.values():
-                    if not child.is_finished():
-                        child.finish(force=force)
-                self.set_status(self.get_raw_status())
-            else:
-                return
-        elif not isinstance(item_status, SPECIAL_STATUS):
+        if item_status == SPECIAL_STATUS.UNFINISHED and not force:
+            return
+
+        if not isinstance(item_status, SPECIAL_STATUS):
             self.set_status(item_status)
 
         super().finish(force=force, override_status=override_status, override_finish_time=override_finish_time)
