@@ -11,9 +11,6 @@ constexpr unsigned int g_default_max_nframes = 64;
 // their stacks may be silently truncated, which is unfortunate.
 constexpr unsigned int g_backend_max_nframes = 512;
 
-// Maximum amount of time, in milliseconds, to wait for crashtracker signal handler
-constexpr uint64_t g_crashtracker_timeout_ms = 5000;
-
 // Default value for the max number of samples to keep in the StaticSamplePool
 constexpr size_t g_default_sample_pool_capacity = 4;
 
@@ -26,7 +23,3 @@ constexpr std::string_view g_language_name = "python";
 
 // Name of the library
 constexpr std::string_view g_library_name = "dd-trace-py";
-
-// These are default settings for crashtracker tags.  These will be moved internally to crashtracker in the near future.
-constexpr std::string_view g_crashtracker_is_crash = "true";
-constexpr std::string_view g_crashtracker_severity = "crash";
