@@ -331,7 +331,23 @@ class BaseModuleWatchdog(abc.ABC):
         # NotImplementedError: Can't perform this operation for unregistered
         pkg_resources = sys.modules.get("pkg_resources")
         if pkg_resources is not None:
-            pkg_resources.register_loader_type(_ImportHookChainedLoader, pkg_resources.DefaultProvider)
+            for _ in range(5):
+                # The package might be in the process of being imported by
+                # another thread by the time this module watchdog is created. If
+                # we fail to find the method we try again after a short wait.
+                # This is likely to happen when a module watchdog is installed
+                # lazily after boot, e.g. as a response to a RC enablement
+                # record. This means that we are unlikely to add delays to the
+                # main or any other use threads.
+                try:
+                    pkg_resources.register_loader_type(_ImportHookChainedLoader, pkg_resources.DefaultProvider)
+                    break
+                except AttributeError:
+                    from time import sleep
+
+                    sleep(0.1)
+            else:
+                log.warning("Cannot ensure correct support with pkg_resources")
 
     def _add_to_meta_path(self) -> None:
         sys.meta_path.insert(0, self)  # type: ignore[arg-type]
