@@ -16,9 +16,11 @@ from typing import TextIO
 import ddtrace
 from ddtrace import config
 import ddtrace.internal.native as native
+from ddtrace.internal.runtime import get_runtime_id
 import ddtrace.internal.utils.http
 from ddtrace.internal.utils.retry import fibonacci_backoff_with_jitter
 from ddtrace.settings._agent import config as agent_config
+from ddtrace.settings.asm import ai_guard_config
 from ddtrace.settings.asm import config as asm_config
 
 from ...constants import _KEEP_SPANS_RATE_KEY
@@ -233,7 +235,9 @@ class HTTPWriter(periodic.PeriodicService, TraceWriter):
 
     def _set_keep_rate(self, trace):
         if trace:
-            trace[0].set_metric(_KEEP_SPANS_RATE_KEY, 1.0 - self._drop_sma.get())
+            trace[0]._metrics[_KEEP_SPANS_RATE_KEY] = (
+                1.0 - self._drop_sma.get()
+            )  # PERF: avoid setting via Span.set_metric
 
     def _reset_connection(self) -> None:
         with self._conn_lck:
@@ -539,6 +543,7 @@ class AgentWriter(HTTPWriter, AgentWriterInterface):
             or in_azure_function()
             or asm_config._asm_enabled
             or asm_config._iast_enabled
+            or ai_guard_config._ai_guard_enabled
         ):
             default_api_version = "v0.4"
 
@@ -731,6 +736,7 @@ class NativeWriter(periodic.PeriodicService, TraceWriter, AgentWriterInterface):
             or in_azure_function()
             or asm_config._asm_enabled
             or asm_config._iast_enabled
+            or ai_guard_config._ai_guard_enabled
         ):
             default_api_version = "v0.4"
 
@@ -808,6 +814,13 @@ class NativeWriter(periodic.PeriodicService, TraceWriter, AgentWriterInterface):
             bucket_size_ns: int = int(stats_interval * 1e9)
             builder.enable_stats(bucket_size_ns)
 
+        # TODO (APMSP-2204): Enable telemetry for all platforms, currently only enabled for Linux.
+        if config._telemetry_enabled and sys.platform.startswith("linux"):
+            heartbeat_ms = int(
+                config._telemetry_heartbeat_interval * 1000
+            )  # Convert DD_TELEMETRY_HEARTBEAT_INTERVAL to milliseconds
+            builder.enable_telemetry(heartbeat_ms, get_runtime_id())
+
         return builder.build()
 
     def set_test_session_token(self, token: Optional[str]) -> None:
@@ -903,7 +916,8 @@ class NativeWriter(periodic.PeriodicService, TraceWriter, AgentWriterInterface):
 
     def _set_keep_rate(self, trace):
         if trace:
-            trace[0].set_metric(_KEEP_SPANS_RATE_KEY, 1.0 - self._drop_sma.get())
+            # PERF: avoid setting via Span.set_metric
+            trace[0]._metrics[_KEEP_SPANS_RATE_KEY] = 1.0 - self._drop_sma.get()
 
     def _send_payload(self, payload: bytes, count: int, client: WriterClientBase):
         try:
