@@ -3,7 +3,9 @@ from typing import Dict
 from typing import List
 from typing import Optional
 
+from ddtrace._trace.pin import Pin
 from ddtrace.internal.constants import COMPONENT
+from ddtrace.internal.logger import get_logger
 from ddtrace.internal.utils.version import parse_version
 from ddtrace.llmobs._constants import CACHE_READ_INPUT_TOKENS_METRIC_KEY
 from ddtrace.llmobs._constants import INPUT_DOCUMENTS
@@ -26,10 +28,12 @@ from ddtrace.llmobs._integrations.utils import openai_set_meta_tags_from_respons
 from ddtrace.llmobs._integrations.utils import update_proxy_workflow_input_output_value
 from ddtrace.llmobs._utils import _get_attr
 from ddtrace.llmobs.utils import Document
-from ddtrace.trace import Pin
 from ddtrace.trace import Span
 
 
+log = get_logger(__name__)
+
+
 class OpenAIIntegration(BaseLLMIntegration):
     _integration_name = "openai"
 
@@ -59,6 +63,7 @@ class OpenAIIntegration(BaseLLMIntegration):
         traced_operations = ("createCompletion", "createChatCompletion", "createEmbedding", "createResponse")
         if operation_id in traced_operations:
             submit_to_llmobs = True
+        log.debug("Creating LLM span for openai operation: %s", operation_id)
         return super().trace(pin, operation_id, submit_to_llmobs, **kwargs)
 
     def _set_base_span_tags(self, span: Span, **kwargs) -> None:
