@@ -6,12 +6,15 @@ from typing import Optional
 from typing import Union
 import weakref
 
+from ddtrace._trace.pin import Pin
 from ddtrace.internal import core
 from ddtrace.internal.logger import get_logger
 from ddtrace.internal.utils import get_argument_value
 from ddtrace.internal.utils.formats import format_trace_id
 from ddtrace.llmobs._constants import AGENT_MANIFEST
+from ddtrace.llmobs._constants import DISPATCH_ON_GUARDRAIL_SPAN_START
 from ddtrace.llmobs._constants import DISPATCH_ON_LLM_TOOL_CHOICE
+from ddtrace.llmobs._constants import DISPATCH_ON_OPENAI_AGENT_SPAN_FINISH
 from ddtrace.llmobs._constants import DISPATCH_ON_TOOL_CALL
 from ddtrace.llmobs._constants import DISPATCH_ON_TOOL_CALL_OUTPUT_USED
 from ddtrace.llmobs._constants import INPUT_MESSAGES
@@ -34,7 +37,7 @@ from ddtrace.llmobs._integrations.utils import OaiTraceAdapter
 from ddtrace.llmobs._utils import _get_nearest_llmobs_ancestor
 from ddtrace.llmobs._utils import _get_span_name
 from ddtrace.llmobs._utils import load_data_value
-from ddtrace.trace import Pin
+from ddtrace.llmobs._utils import safe_json
 from ddtrace.trace import Span
 
 
@@ -79,6 +82,10 @@ class OpenAIAgentsIntegration(BaseLLMIntegration):
         elif oai_span:
             self.oai_to_llmobs_span[oai_span.span_id] = llmobs_span
             self._llmobs_update_trace_info_input(oai_span, llmobs_span)
+
+            if oai_span.span_type == "guardrail":
+                core.dispatch(DISPATCH_ON_GUARDRAIL_SPAN_START, (llmobs_span,))
+
         return llmobs_span
 
     def _llmobs_set_tags(
@@ -131,6 +138,7 @@ class OpenAIAgentsIntegration(BaseLLMIntegration):
             self._llmobs_set_handoff_attributes(span, oai_span)
         elif span_type == "agent":
             self._llmobs_set_agent_attributes(span, oai_span)
+            core.dispatch(DISPATCH_ON_OPENAI_AGENT_SPAN_FINISH, ())
         elif span_type == "custom":
             custom_data = oai_span.formatted_custom_data
             if custom_data:
@@ -225,13 +233,13 @@ class OpenAIAgentsIntegration(BaseLLMIntegration):
         if oai_span.response and oai_span.response.output:
             messages, tool_call_outputs = oai_span.llmobs_output_messages()
 
-            for tool_id, tool_name, tool_args in tool_call_outputs:
+            for tool_call_output in tool_call_outputs:
                 core.dispatch(
                     DISPATCH_ON_LLM_TOOL_CHOICE,
                     (
-                        tool_id,
-                        tool_name,
-                        tool_args,
+                        tool_call_output["tool_id"],
+                        tool_call_output["name"],
+                        safe_json(tool_call_output["arguments"]),
                         {
                             "trace_id": format_trace_id(span.trace_id),
                             "span_id": str(span.span_id),
