@@ -15,6 +15,7 @@ from ddtrace.llmobs._constants import MODEL_PROVIDER
 from ddtrace.llmobs._constants import OUTPUT_MESSAGES
 from ddtrace.llmobs._constants import OUTPUT_TOKENS_METRIC_KEY
 from ddtrace.llmobs._constants import SPAN_KIND
+from ddtrace.llmobs._constants import TOOL_DEFINITIONS
 from ddtrace.llmobs._constants import TOTAL_TOKENS_METRIC_KEY
 from ddtrace.llmobs._integrations.base import BaseLLMIntegration
 from ddtrace.llmobs._integrations.google_utils import extract_message_from_part_gemini_vertexai
@@ -61,6 +62,10 @@ class VertexAIIntegration(BaseLLMIntegration):
             output_messages = self._extract_output_message(response)
             metrics = self._extract_metrics_from_response(response)
 
+        tool_definitions = self._extract_tools(instance, kwargs.get("tools", []))
+        if tool_definitions:
+            span._set_ctx_item(TOOL_DEFINITIONS, tool_definitions)
+
         span._set_ctx_items(
             {
                 SPAN_KIND: "llm",
@@ -173,3 +178,24 @@ class VertexAIIntegration(BaseLLMIntegration):
             message = extract_message_from_part_gemini_vertexai(part, role)
             messages.append(message)
         return messages
+
+    def _extract_tools(self, instance, arg_tools):
+        """
+        Extracts tool definitions for a call, tools can be passed into a model instance or a generation call, so we
+        handle both cases and remove duplicates.
+        """
+        tools = _get_attr(instance, "_tools", []) or []
+        tool_set = set(tools)
+        tool_set.update(arg_tools)
+        tool_definitions = []
+        for tool in tool_set:
+            tool_dict = tool.to_dict()
+            function_declarations = _get_attr(tool_dict, "function_declarations", [])
+            for function in function_declarations:
+                tool_definition_info = {
+                    "name": _get_attr(function, "name", "") or "",
+                    "description": _get_attr(function, "description", "") or "",
+                    "schema": _get_attr(function, "parameters", {}) or {},
+                }
+                tool_definitions.append(tool_definition_info)
+        return tool_definitions
