@@ -5,6 +5,7 @@ import json
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Set
 from typing import Tuple
 from typing import Union
 
@@ -88,23 +89,6 @@ def validate_prompt(prompt: dict) -> Dict[str, Union[str, dict, List[str]]]:
     return validated_prompt
 
 
-class LinkTracker:
-    def __init__(self, object_span_links=None):
-        self._object_span_links = object_span_links or {}
-
-    def get_object_id(self, obj):
-        return f"{type(obj).__name__}_{id(obj)}"
-
-    def add_span_links_to_object(self, obj, span_links):
-        obj_id = self.get_object_id(obj)
-        if obj_id not in self._object_span_links:
-            self._object_span_links[obj_id] = []
-        self._object_span_links[obj_id] += span_links
-
-    def get_span_links_from_object(self, obj):
-        return self._object_span_links.get(self.get_object_id(obj), [])
-
-
 class AnnotationContext:
     def __init__(self, _register_annotator, _deregister_annotator):
         self._register_annotator = _register_annotator
@@ -180,7 +164,7 @@ def _get_ml_app(span: Span) -> Optional[str]:
         if ml_app is not None:
             return ml_app
         llmobs_parent = _get_nearest_llmobs_ancestor(llmobs_parent)
-    return ml_app or span.context._meta.get(PROPAGATED_ML_APP_KEY) or config._llmobs_ml_app
+    return ml_app or span.context._meta.get(PROPAGATED_ML_APP_KEY) or config._llmobs_ml_app or config.service
 
 
 def _get_session_id(span: Span) -> Optional[str]:
@@ -217,6 +201,14 @@ def safe_json(obj, ensure_ascii=True):
         log.error("Failed to serialize object to JSON.", exc_info=True)
 
 
+def safe_load_json(value: str):
+    try:
+        loaded_value = json.loads(value)
+    except (json.JSONDecodeError, TypeError):
+        loaded_value = {"value": str(value)}
+    return loaded_value
+
+
 def load_data_value(value):
     if isinstance(value, (list, tuple, set)):
         return [load_data_value(item) for item in value]
@@ -236,6 +228,20 @@ def load_data_value(value):
             return value_str
 
 
+def format_tool_call_arguments(tool_args: str) -> str:
+    """
+    Format tool call arguments as a JSON string with no unnecessary whitespace.
+
+    This is used to ensure that tool call arguments are properly formatted for span linking purposes.
+    """
+    formatted_tool_args = str(tool_args)
+    try:
+        formatted_tool_args = json.dumps(json.loads(tool_args), separators=(",", ":"))
+    except (json.JSONDecodeError, TypeError):
+        pass
+    return formatted_tool_args
+
+
 def add_span_link(span: Span, span_id: str, trace_id: str, from_io: str, to_io: str) -> None:
     current_span_links = span._get_ctx_item(SPAN_LINKS) or []
     current_span_links.append(
@@ -273,40 +279,60 @@ class TrackedToolCall:
     arguments: str
     llm_span_context: Dict[str, str]  # span/trace id of the LLM span that initiated this tool call
     tool_span_context: Optional[Dict[str, str]] = None  # span/trace id of the tool span that executed this call
-    is_handoff_completed: bool = False  # Track if handoff is completed to noisy links
     tool_kind: str = "function"  # one of "function", "handoff"
 
 
-class ToolCallTracker:
-    """Used to track tool data and their associated llm/tool spans for span linking."""
+class LinkTracker:
+    """
+    This class is used to create span links across integrations.
+
+    The primary use cases are:
+    - Linking LLM spans to their associated tool spans and vice versa
+    - Linking LLM spans to their associated guardrail spans and vice versa
+    """
 
     def __init__(self):
         self._tool_calls: Dict[str, TrackedToolCall] = {}  # maps tool id's to tool call data
         self._lookup_tool_id: Dict[Tuple[str, str], str] = {}  # maps (tool_name, arguments) to tool id's
+        self._active_guardrail_spans: Set[Span] = set()
+        self._last_llm_span: Optional[Span] = None
 
     def on_llm_tool_choice(
         self, tool_id: str, tool_name: str, arguments: str, llm_span_context: Dict[str, str]
     ) -> None:
         """
         Called when an llm span finishes. This is used to save the tool choice information generated by an LLM
-        for
+        for future span linking purposes.
+
+        We make the assumption that there is only one ongoing tool call per (tool_name, arguments) pair possible.
+        This is to avoid some issues with parsing tool calls from ReAct agents which format tool calls as plain text.
         """
+        formatted_arguments = format_tool_call_arguments(arguments)
+        if self._lookup_tool_id.get((tool_name, formatted_arguments)):
+            return
+
         tool_call = TrackedToolCall(
             tool_id=tool_id,
             tool_name=tool_name,
-            arguments=arguments,
+            arguments=formatted_arguments,
             llm_span_context=llm_span_context,
         )
         self._tool_calls[tool_id] = tool_call
-        self._lookup_tool_id[(tool_name, arguments)] = tool_id
+        self._lookup_tool_id[(tool_name, formatted_arguments)] = tool_id
 
-    def on_tool_call(self, tool_name: str, tool_arg: str, tool_kind: str, tool_span: Span) -> None:
+    def on_tool_call(
+        self, tool_name: str, tool_arg: str, tool_kind: str, tool_span: Span, tool_id: Optional[str] = None
+    ) -> None:
         """
         Called when a tool span finishes. This is used to link the input of the tool span to the output
         of the LLM span responsible for generating it's input. We also save the span/trace id of the tool call
         so that we can link to the input of an LLM span if it's output is used in an LLM call.
+
+        If possible, we use the tool_id provided to lookup the tool call; otherwise, we perform a best effort
+        lookup based on the tool_name and tool_arg.
         """
-        tool_id = self._lookup_tool_id.get((tool_name, tool_arg))
+        formatted_tool_arg = format_tool_call_arguments(tool_arg)
+        tool_id = tool_id or self._lookup_tool_id.get((tool_name, formatted_tool_arg))
         if not tool_id:
             return
         tool_call = self._tool_calls.get(tool_id)
@@ -324,26 +350,20 @@ class ToolCallTracker:
             "trace_id": format_trace_id(tool_span.trace_id),
         }
         self._tool_calls[tool_id].tool_kind = tool_kind
-        self._lookup_tool_id.pop((tool_name, tool_arg))
+        self._lookup_tool_id.pop((tool_name, formatted_tool_arg), None)
 
     def on_tool_call_output_used(self, tool_id: str, llm_span: Span) -> None:
         """
         Called when an LLM span finishes. This is used to link the output of a tool call to the input of an
         LLM span.
 
-        For handoff tool calls, we need to mark the handoff as completed since we only want to link
-        the output of a handoff tool span to the FIRST LLM call that has that handoff as input.
-
-        For function tool calls, the tool output is used as context for every LLM call that has that tool call
-        as an input.
+        The tool call is removed from the tracker since we only want to link the output of a tool call to the FIRST
+        LLM call that has that tool call as an input to reduce noisy links.
         """
-        tool_call = self._tool_calls.get(tool_id)
-        if not tool_call or not tool_call.tool_span_context or tool_call.is_handoff_completed:
+        tool_call = self._tool_calls.pop(tool_id, None)
+        if not tool_call or not tool_call.tool_span_context:
             return
 
-        if tool_call.tool_kind == "handoff":
-            self._tool_calls[tool_id].is_handoff_completed = True
-
         add_span_link(
             llm_span,
             tool_call.tool_span_context["span_id"],
@@ -351,3 +371,47 @@ class ToolCallTracker:
             "output",
             "input",
         )
+
+    def on_llm_span_finish(self, span: Span) -> None:
+        """
+        Called when an LLM span event is created. If the LLM span is the first LLM span,
+        it will consume all active guardrail links.
+        """
+        self._last_llm_span = span
+        spans_to_remove = set()
+        for guardrail_span in self._active_guardrail_spans:
+            # some guardrail spans may have LLM spans as children which we don't want to link to
+            if _get_nearest_llmobs_ancestor(guardrail_span) == _get_nearest_llmobs_ancestor(span):
+                add_span_link(
+                    span,
+                    str(guardrail_span.span_id),
+                    format_trace_id(guardrail_span.trace_id),
+                    "output",
+                    "input",
+                )
+                spans_to_remove.add(guardrail_span)
+        self._active_guardrail_spans -= spans_to_remove
+
+    def on_guardrail_span_start(self, span: Span) -> None:
+        """
+        Called when a guardrail span starts. This is used to track the active guardrail
+        spans and link the output of the last LLM span to the input of the guardrail span.
+        """
+        self._active_guardrail_spans.add(span)
+        if self._last_llm_span is not None and _get_nearest_llmobs_ancestor(span) == _get_nearest_llmobs_ancestor(
+            self._last_llm_span
+        ):
+            add_span_link(
+                span,
+                str(self._last_llm_span.span_id),
+                format_trace_id(self._last_llm_span.trace_id),
+                "output",
+                "input",
+            )
+
+    def on_openai_agent_span_finish(self) -> None:
+        """
+        Called when an OpenAI agent span finishes. This is used to reset the last LLM span
+        since output guardrails are only linked to the last LLM span for a particular agent.
+        """
+        self._last_llm_span = None
