@@ -283,6 +283,11 @@ def login_user_sdk():
     return "login failure", 401
 
 
+@app.route("/buggy_endpoint/", methods=None)
+def buggy_endpoint():
+    return ""
+
+
 @app.before_request
 def service_renaming():
     if request.headers.get("x-rename-service", "false") == "true":
