@@ -18,7 +18,6 @@ from ddtrace.appsec._iast._taint_tracking.aspects import add_aspect
 from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
 from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 from tests.appsec.iast.iast_utils import iast_hypothesis_test
-from tests.utils import override_env
 from tests.utils import override_global_config
 
 
@@ -344,9 +343,7 @@ def test_propagate_ranges_with_no_context(caplog):
     )
 
     reset_context()
-    with override_env({"_DD_IAST_USE_ROOT_SPAN": "false"}), override_global_config(
-        dict(_iast_debug=True)
-    ), caplog.at_level(logging.DEBUG):
+    with override_global_config(dict(_iast_debug=True)), caplog.at_level(logging.DEBUG):
         result_2 = add_aspect(result, "another_string")
 
     create_context()
