@@ -1,4 +1,3 @@
-import json
 from urllib.parse import urlencode
 
 from django import VERSION as DJANGO_VERSION
@@ -20,9 +19,9 @@ from ddtrace.settings.asm import config as asm_config
 from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
 from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 from tests.appsec.iast.iast_utils import get_line_and_hash
+from tests.appsec.iast.iast_utils import load_iast_report
 from tests.appsec.integrations.django_tests.utils import _aux_appsec_get_root_span
 from tests.utils import TracerSpanContainer
-from tests.utils import flaky
 from tests.utils import override_global_config
 
 
@@ -63,9 +62,9 @@ def _aux_appsec_get_root_span_with_exception(
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
 def test_django_weak_hash(client, iast_span, tracer):
     root_span, _ = _aux_appsec_get_root_span(client, iast_span, tracer, url="/appsec/weak-hash/")
-    str_json = root_span.get_tag(IAST.JSON)
-    assert str_json is not None, "no JSON tag in root span"
-    vulnerability = json.loads(str_json)["vulnerabilities"][0]
+    data_iast = load_iast_report(root_span)
+    assert data_iast is not None, "no iast vulns in root span"
+    vulnerability = data_iast["vulnerabilities"][0]
     assert vulnerability["location"]["path"].endswith(TEST_FILE)
     assert type(vulnerability["location"]["spanId"]) is int
     assert vulnerability["location"]["spanId"] > 0
@@ -167,7 +166,7 @@ def test_django_tainted_user_agent_iast_disabled(client, iast_span, tracer):
             headers={"HTTP_USER_AGENT": "test/1.2.3"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"test/1.2.3"
@@ -237,7 +236,7 @@ def test_django_sqli_http_request_parameter(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"test/1.2.3"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("iast_enabled_sqli_http_request_parameter", vuln_type, filename=TEST_FILE)
 
@@ -289,7 +288,7 @@ def test_django_sqli_http_request_parameter_name_get_and_stacktrace(client, iast
     # api_version = iast_span.tracer._span_aggregator.writer._api_version
     # assert api_version == "v0.4", f"Agent API version {api_version} not supported"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     assert get_iast_stack_trace(root_span)
     line, hash_value = get_line_and_hash(
         "iast_enabled_sqli_http_request_parameter_name_get", vuln_type, filename=TEST_FILE
@@ -342,7 +341,7 @@ def test_django_sqli_http_request_parameter_name_post(client, iast_span, tracer)
     assert response.status_code == 200
     assert response.content == b"test/1.2.3"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash(
         "iast_enabled_sqli_http_request_parameter_name_post", vuln_type, filename=TEST_FILE
@@ -392,7 +391,7 @@ def test_django_sqli_query_no_redacted(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"OK"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("sqli_query_no_redacted", vuln_type, filename=TEST_FILE)
 
@@ -433,7 +432,7 @@ def test_django_sqli_http_request_header_value(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"master"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     assert loaded["sources"] == [{"origin": "http.request.header", "name": "HTTP_USER_AGENT", "value": "master"}]
     assert loaded["vulnerabilities"][0]["type"] == VULN_SQL_INJECTION
@@ -468,7 +467,7 @@ def test_django_iast_disabled_sqli_http_request_header_value(client, iast_span,
             headers={"HTTP_USER_AGENT": "master"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"master"
@@ -490,7 +489,7 @@ def test_django_sqli_http_request_header_name(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"test/1.2.3"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     assert loaded["sources"] == [{"origin": "http.request.header.name", "name": "master", "value": "master"}]
     assert loaded["vulnerabilities"][0]["type"] == VULN_SQL_INJECTION
@@ -525,7 +524,7 @@ def test_django_iast_disabled_sqli_http_request_header_name(client, iast_span, t
             headers={"master": "test/1.2.3"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"test/1.2.3"
@@ -544,7 +543,7 @@ def test_django_sqli_http_path_parameter(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"test/1.2.3"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     assert loaded["sources"] == [
         {"origin": "http.request.path.parameter", "name": "q_http_path_parameter", "value": "sqlite_master"}
@@ -578,7 +577,7 @@ def test_django_iast_disabled_sqli_http_path_parameter(client, iast_span, tracer
             headers={"HTTP_USER_AGENT": "test/1.2.3"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"test/1.2.3"
@@ -597,7 +596,7 @@ def test_django_sqli_http_cookies_name(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"test/1.2.3"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     vulnerability = False
     for vuln in loaded["vulnerabilities"]:
@@ -635,7 +634,7 @@ def test_django_iast_disabled_sqli_http_cookies_name(client, iast_span, tracer):
             cookies={"master": "test/1.2.3"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"test/1.2.3"
@@ -654,7 +653,7 @@ def test_django_sqli_http_cookies_value(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"master"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     vulnerability = False
     for vuln in loaded["vulnerabilities"]:
@@ -694,7 +693,7 @@ def test_django_iast_disabled_sqli_http_cookies_value(client, iast_span, tracer)
             cookies={"master": "master"},
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"master"
@@ -718,7 +717,7 @@ def test_django_sqli_http_body(client, iast_span, tracer, payload, content_type)
         payload=payload,
         content_type=content_type,
     )
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("iast_enabled_sqli_http_body", VULN_SQL_INJECTION, filename=TEST_FILE)
 
@@ -777,7 +776,7 @@ def test_django_tainted_http_body_empty(client, iast_span, tracer, payload, cont
             payload=payload,
             content_type=content_type,
         )
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b""
@@ -796,7 +795,7 @@ def test_django_iast_disabled_sqli_http_body(client, iast_span, tracer):
             content_type="application/json",
         )
 
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
 
         assert response.status_code == 200
         assert response.content == b"master"
@@ -811,7 +810,7 @@ def test_django_querydict(client, iast_span, tracer):
         url="/appsec/validate_querydict/?x=1&y=2&x=3",
     )
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
     assert response.status_code == 200
     assert (
         response.content == b"x=['1', '3'], all=[('x', ['1', '3']), ('y', ['2'])],"
@@ -830,7 +829,7 @@ def test_django_command_injection(client, iast_span, tracer):
         content_type="application/json",
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("iast_command_injection", VULN_CMDI, filename=TEST_FILE)
 
@@ -861,7 +860,7 @@ def test_django_command_injection_subprocess(client, iast_span, tracer):
         content_type="application/x-www-form-urlencoded",
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("iast_command_injection_subprocess", VULN_CMDI, filename=TEST_FILE)
 
@@ -926,8 +925,9 @@ def test_django_command_injection_secure_mark(client, iast_span, tracer):
         content_type="application/json",
     )
 
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
+    assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_SUPPRESSED_VULNERABILITY + ".command_injection")
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -941,7 +941,7 @@ def test_django_xss_secure_mark(client, iast_span, tracer):
         content_type="application/json",
     )
 
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -997,9 +997,10 @@ def test_django_command_injection_security_control(client, tracer, security_cont
             content_type="application/json",
         )
 
-        loaded = root_span.get_tag(IAST.JSON)
+        loaded = load_iast_report(root_span)
         if match_function:
             assert loaded is None
+            assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_SUPPRESSED_VULNERABILITY + ".command_injection")
         else:
             assert loaded is not None
         _end_iast_context_and_oce()
@@ -1020,7 +1021,7 @@ def test_django_header_injection_secure(client, iast_span, tracer):
         assert response._headers["header-injection"] == ("Header-Injection", "master")
     else:
         assert response.headers["Header-Injection"] == "master"
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -1040,7 +1041,7 @@ def test_django_header_injection(client, iast_span, tracer):
         assert response._headers["header-injection"] == ("Header-Injection", "master\r\nInjected-Header: 1234")
     else:
         assert response.headers["Header-Injection"] == "master\r\nInjected-Header: 1234"
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     assert loaded["sources"] == [
         {"origin": "http.request.body", "name": "http.request.body", "value": "master\r\nInjected-Header: 1234"}
@@ -1059,7 +1060,7 @@ def test_django_unvalidated_redirect_url(client, iast_span, tracer):
         client, iast_span, tracer, url=f"/appsec/unvalidated_redirect_url/?url={tainted_value}"
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("unvalidated_redirect_url", VULN_UNVALIDATED_REDIRECT, filename=TEST_FILE)
 
@@ -1083,7 +1084,7 @@ def test_django_unvalidated_redirect_url_validator(client, iast_span, tracer):
         client, iast_span, tracer, url=f"/appsec/unvalidated_redirect_url_validator/?url={tainted_value}"
     )
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1093,7 +1094,7 @@ def test_django_unvalidated_redirect_url_header(client, iast_span, tracer):
         client, iast_span, tracer, url=f"/appsec/unvalidated_redirect_url_header/?url={tainted_value}"
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     assert loaded["sources"] == [
         {"origin": "http.request.parameter", "name": "url", "value": "http://www.malicious.com.ar.uk/muahahaha"}
@@ -1114,7 +1115,7 @@ def test_django_unvalidated_redirect_path(client, iast_span, tracer):
         client, iast_span, tracer, url=f"/appsec/unvalidated_redirect_path/?url={tainted_value}"
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     line, hash_value = get_line_and_hash("unvalidated_redirect_path", VULN_UNVALIDATED_REDIRECT, filename=TEST_FILE)
 
     assert loaded["sources"] == [{"origin": "http.request.parameter", "name": "url", "value": "muahahaha"}]
@@ -1138,7 +1139,7 @@ def test_django_unvalidated_redirect_safe_source_cookie(client, iast_span, trace
         cookies={"url": tainted_value},
     )
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1152,7 +1153,7 @@ def test_django_unvalidated_redirect_safe_source_header(client, iast_span, trace
         headers={"url": tainted_value},
     )
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1166,7 +1167,7 @@ def test_django_unvalidated_redirect_path_multiple_sources(client, iast_span, tr
         headers={"url": "muahahaha"},
     )
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     line, hash_value = get_line_and_hash(
         "unvalidated_redirect_path_multiple_sources", VULN_UNVALIDATED_REDIRECT, filename=TEST_FILE
     )
@@ -1195,7 +1196,7 @@ def test_django_insecure_cookie(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     assert loaded["sources"] == []
     assert len(loaded["vulnerabilities"]) == 1
     vulnerability = loaded["vulnerabilities"][0]
@@ -1219,7 +1220,7 @@ def test_django_insecure_cookie_secure(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1233,7 +1234,7 @@ def test_django_insecure_cookie_empty_cookie(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    assert root_span.get_tag(IAST.JSON) is None
+    assert load_iast_report(root_span) is None
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1247,7 +1248,7 @@ def test_django_insecure_cookie_2_insecure_1_secure(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     assert loaded["sources"] == []
     assert len(loaded["vulnerabilities"]) == 2
 
@@ -1263,7 +1264,7 @@ def test_django_insecure_cookie_special_characters(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     assert loaded["sources"] == []
     assert len(loaded["vulnerabilities"]) == 1
     vulnerability = loaded["vulnerabilities"][0]
@@ -1289,7 +1290,7 @@ def test_django_stacktrace_leak(client, iast_span, tracer):
 
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     assert loaded["sources"] == []
     assert len(loaded["vulnerabilities"]) == 1
     vulnerability = loaded["vulnerabilities"][0]
@@ -1302,7 +1303,7 @@ def test_django_stacktrace_leak(client, iast_span, tracer):
     assert vulnerability["hash"]
 
 
-@flaky(until=1767220930, reason="This test fails on Python 3.10 and below, and on Django versions below 4.2")
+@pytest.mark.skip(reason="This test fails on Python 3.10 and below, and on Django versions below 4.2")
 def test_django_stacktrace_from_technical_500_response(client, iast_span, tracer, debug_mode):
     root_span, response = _aux_appsec_get_root_span(
         client,
@@ -1315,7 +1316,7 @@ def test_django_stacktrace_from_technical_500_response(client, iast_span, tracer
     assert response.status_code == 500, "Expected a 500 status code"
     assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
     # technical_500_response reports a XSS also
     vulnerability = [vln for vln in loaded["vulnerabilities"] if vln["type"] == VULN_STACKTRACE_LEAK][0]
     assert vulnerability["evidence"] == {
@@ -1339,7 +1340,7 @@ def test_django_xss(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"<html>\n<body>\n<p>Input: <script>alert('XSS')</script></p>\n</body>\n</html>"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("xss_http_request_parameter_mark_safe", vuln_type, filename=TEST_FILE)
 
@@ -1375,7 +1376,7 @@ def test_django_xss_safe_template_tag(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"<html>\n<body>\n<p>Input: <script>alert('XSS')</script></p>\n</body>\n</html>"
 
-    loaded = json.loads(root_span.get_tag(IAST.JSON))
+    loaded = load_iast_report(root_span)
 
     line, hash_value = get_line_and_hash("xss_http_request_parameter_template_safe", vuln_type, filename=TEST_FILE)
 
@@ -1417,7 +1418,7 @@ def test_django_xss_autoscape(client, iast_span, tracer):
             response.content
             == b"<html>\n<body>\n<p>\n    &lt;script&gt;alert(&#39;XSS&#39;)&lt;/script&gt;\n</p>\n</body>\n</html>\n"
         ), f"Error. content is {response.content}"
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -1441,7 +1442,7 @@ def test_django_xss_secure(client, iast_span, tracer):
             response.content
             == b"<html>\n<body>\n<p>Input: &lt;script&gt;alert(&#39;XSS&#39;)&lt;/script&gt;</p>\n</body>\n</html>"
         ), f"COntent: {response.content}"
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -1456,7 +1457,7 @@ def test_django_ospathjoin_propagation(client, iast_span, tracer):
     assert response.status_code == 200
     assert response.content == b"OK:True:False:False", response.content
 
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -1472,7 +1473,7 @@ def test_django_iast_sampling(client, test_spans_2_vuln_per_request_deduplicatio
         )
         assert response.status_code == 200
         assert str(response.content, encoding="utf-8") == f"OK:value{i}", response.content
-        loaded = json.loads(root_span.get_tag(IAST.JSON))
+        loaded = load_iast_report(root_span)
         assert len(loaded["vulnerabilities"]) == 1
         assert loaded["sources"] == [
             {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
@@ -1498,9 +1499,9 @@ def test_django_iast_sampling_2(client, test_spans_2_vuln_per_request_deduplicat
         assert response.status_code == 200
         assert str(response.content, encoding="utf-8") == f"OK:value{i}", response.content
         if i > 0:
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
         else:
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert len(loaded["vulnerabilities"]) == 2
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
@@ -1524,9 +1525,9 @@ def test_django_iast_sampling_by_route_method(client, test_spans_2_vuln_per_requ
         assert response.status_code == 200
         assert str(response.content, encoding="utf-8") == f"OK:value{i}:{i}", response.content
         if i > 7:
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
         else:
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert len(loaded["vulnerabilities"]) == 2
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
@@ -1545,7 +1546,7 @@ def test_django_ssrf_safe_path(client, iast_span, tracer):
     root_span, _ = _aux_appsec_get_root_span(
         client, iast_span, tracer, url=f"/appsec/ssrf_requests/?url={tainted_value}"
     )
-    loaded = root_span.get_tag(IAST.JSON)
+    loaded = load_iast_report(root_span)
     assert loaded is None
 
 
@@ -1597,11 +1598,11 @@ def test_django_ssrf_url(client, iast_span, tracer, option, url, value_parts):
     assert response.content == b"OK"
 
     if value_parts is None:
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
     elif option == "safe_host" and DJANGO_VERSION >= (3, 1):
-        assert root_span.get_tag(IAST.JSON) is None
+        assert load_iast_report(root_span) is None
     else:
-        loaded = json.loads(root_span.get_tag(IAST.JSON))
+        loaded = load_iast_report(root_span)
 
         line, hash_value = get_line_and_hash(f"ssrf_requests_{option}", VULN_SSRF, filename=TEST_FILE)
 
