@@ -1,6 +1,7 @@
 """
 Ensure that cached functions are invalidated between test runs.
 """
+
 import pytest
 
 from ddtrace.internal.utils import cache
@@ -26,6 +27,6 @@ cache.cached = wrapped_cached
 @pytest.hookimpl(hookwrapper=True)
 def pytest_runtest_teardown(item, nextitem):
     for f in _CACHED_FUNCTIONS:
-        f.invalidate()
+        f.cache_clear()
 
     yield
