@@ -3,9 +3,9 @@ from functools import wraps
 import celery
 import pytest
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.celery.patch import patch
 from ddtrace.contrib.internal.celery.patch import unpatch
-from ddtrace.trace import Pin
 from tests.utils import TracerTestCase
 
 from ..config import RABBITMQ_CONFIG
