@@ -3,9 +3,9 @@ import os
 import dogpile
 import pytest
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.dogpile_cache.patch import patch
 from ddtrace.contrib.internal.dogpile_cache.patch import unpatch
-from ddtrace.trace import Pin
 from tests.conftest import DEFAULT_DDTRACE_SUBPROCESS_TEST_SERVICE_NAME
 from tests.utils import DummyTracer
 from tests.utils import TracerSpanContainer
