@@ -1,9 +1,9 @@
 import flask
 import mock
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.flask.patch import flask_version
 from ddtrace.contrib.internal.flask.patch import unpatch
-from ddtrace.trace import Pin
 
 from . import BaseFlaskTestCase
 
