@@ -4,9 +4,10 @@ import http.client as httplib
 
 import wrapt
 
+from ddtrace._trace.pin import Pin
+
 # Project
 from ddtrace._trace.span import _get_64_highest_order_bits_as_hex
-from ddtrace.trace import Pin
 from tests.utils import TracerTestCase
 
 from .test_httplib import SOCKET
@@ -70,14 +71,23 @@ class TestHTTPLibDistributed(HTTPLibBaseMixin, TracerTestCase):
 
     def test_propagation_connection_true(self):
         conn = self.get_http_connection(SOCKET)
-        cfg = Pin._get_config(conn)
+
+        cfg = {}
+        pin = Pin.get_from(conn)
+        if pin:
+            cfg = pin._config
         cfg["distributed_tracing"] = True
         self.request(conn=conn)
         self.check_enabled()
 
     def test_propagation_connection_false(self):
         conn = self.get_http_connection(SOCKET)
-        cfg = Pin._get_config(conn)
+
+        cfg = {}
+        pin = Pin.get_from(conn)
+        if pin:
+            cfg = pin._config
+
         cfg["distributed_tracing"] = False
         self.request(conn=conn)
         self.check_disabled()
