@@ -9,13 +9,12 @@ from pymemcache.exceptions import MemcacheUnknownError
 import pytest
 import wrapt
 
+# project
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.pymemcache.client import WrappedClient
 from ddtrace.contrib.internal.pymemcache.patch import patch
 from ddtrace.contrib.internal.pymemcache.patch import unpatch
 from ddtrace.internal.schema import DEFAULT_SPAN_SERVICE_NAME
-
-# project
-from ddtrace.trace import Pin
 from tests.utils import DummyTracer
 from tests.utils import TracerTestCase
 from tests.utils import override_config
