@@ -94,7 +94,13 @@ class UnittestSnapshotTestCase(TracerTestCase):
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             text=True,
-            env=_get_default_ci_env_vars(dict(DD_API_KEY="foobar.baz", DD_CIVISIBILITY_AGENTLESS_ENABLED="false")),
+            env=_get_default_ci_env_vars(
+                dict(
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
+                )
+            ),
         )
 
     @snapshot(ignores=SNAPSHOT_IGNORES + SNAPSHOT_IGNORES_ITR_COVERAGE + SNAPSHOT_IGNORES_GITLAB)
@@ -136,7 +142,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             text=True,
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -177,7 +187,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
         with override_env(
             _get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
             replace_os_env=True,
@@ -236,7 +250,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -299,7 +317,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -363,7 +385,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -431,7 +457,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -504,7 +534,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -581,7 +615,11 @@ class UnittestSnapshotTestCase(TracerTestCase):
             ["ddtrace-run", "python", "-m", "unittest"],
             env=_get_default_ci_env_vars(
                 dict(
-                    DD_API_KEY="foobar.baz", DD_CIVISIBILITY_ITR_ENABLED="1", DD_CIVISIBILITY_AGENTLESS_ENABLED="false"
+                    DD_API_KEY="foobar.baz",
+                    DD_CIVISIBILITY_ITR_ENABLED="1",
+                    DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -647,7 +685,9 @@ class UnittestSnapshotTestCase(TracerTestCase):
                     DD_API_KEY="foobar.baz",
                     DD_CIVISIBILITY_ITR_ENABLED="1",
                     DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_ITR_SUITE_MODE="false",
                     DD_TAGS="test.configuration.custom_key:some_value",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
@@ -689,6 +729,7 @@ class UnittestSnapshotTestCase(TracerTestCase):
                     DD_API_KEY="foobar.baz",
                     DD_PATCH_MODULES="sqlite3:false",
                     DD_CIVISIBILITY_AGENTLESS_ENABLED="false",
+                    _DD_CIVISIBILITY_DISABLE_EVP_PROXY="true",
                 )
             ),
         )
