@@ -6,9 +6,9 @@ import pytest
 from wrapt import ObjectProxy
 import yaaredis
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.yaaredis.patch import patch
 from ddtrace.contrib.internal.yaaredis.patch import unpatch
-from ddtrace.trace import Pin
 from tests.opentracer.utils import init_tracer
 from tests.utils import override_config
 
