@@ -576,7 +576,7 @@ assert span.get_tag("header_tag_420") is None
 assert span.get_tag("env_set_tag_name") == "helloworld"
 
 config._http._reset()
-config._header_tag_name.invalidate()
+config._header_tag_name.cache_clear()
 call_apm_tracing_rc(_base_rc_config({"tracing_header_tags":
     [{"header": "X-Header-Tag-420", "tag_name":"header_tag_420"}]}), config)
 
@@ -588,7 +588,7 @@ assert span2.get_tag("header_tag_420") == "foobarbanana", span2._meta
 assert span2.get_tag("env_set_tag_name") is None
 
 config._http._reset()
-config._header_tag_name.invalidate()
+config._header_tag_name.cache_clear()
 call_apm_tracing_rc(_base_rc_config({}), config)
 
 with tracer.trace("test") as span3:
