@@ -873,3 +873,29 @@ def _assert_span_link(from_span_event, to_span_event, from_io, to_io):
             found = True
             break
     assert found
+
+
+def iterate_stream(stream):
+    for _ in stream:
+        pass
+
+
+async def aiterate_stream(stream):
+    async for _ in stream:
+        pass
+
+
+def next_stream(stream):
+    while True:
+        try:
+            next(stream)
+        except StopIteration:
+            break
+
+
+async def anext_stream(stream):
+    while True:
+        try:
+            await stream.__anext__()
+        except StopAsyncIteration:
+            break
